==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/ModelContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.ModelContainerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property containerHostname The DNS host name for the container.
 * @property environment Environment variables for the Docker container.
 * A list of key value pairs.
 * @property image The registry path where the inference code image is stored in Amazon ECR.
 * @property imageConfig Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
 * @property mode The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
 * @property modelDataSource The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
 * @property modelDataUrl The URL for the S3 location where model artifacts are stored.
 * @property modelPackageName The Amazon Resource Name (ARN) of the model package to use to create the model.
 */
public data class ModelContainerArgs(
    public val containerHostname: Output<String>? = null,
    public val environment: Output<Map<String, String>>? = null,
    public val image: Output<String>? = null,
    public val imageConfig: Output<ModelContainerImageConfigArgs>? = null,
    public val mode: Output<String>? = null,
    public val modelDataSource: Output<ModelContainerModelDataSourceArgs>? = null,
    public val modelDataUrl: Output<String>? = null,
    public val modelPackageName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.ModelContainerArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.ModelContainerArgs =
        com.pulumi.aws.sagemaker.inputs.ModelContainerArgs.builder()
            .containerHostname(containerHostname?.applyValue({ args0 -> args0 }))
            .environment(
                environment?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .image(image?.applyValue({ args0 -> args0 }))
            .imageConfig(imageConfig?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mode(mode?.applyValue({ args0 -> args0 }))
            .modelDataSource(modelDataSource?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .modelDataUrl(modelDataUrl?.applyValue({ args0 -> args0 }))
            .modelPackageName(modelPackageName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ModelContainerArgs].
 */
@PulumiTagMarker
public class ModelContainerArgsBuilder internal constructor() {
    private var containerHostname: Output<String>? = null

    private var environment: Output<Map<String, String>>? = null

    private var image: Output<String>? = null

    private var imageConfig: Output<ModelContainerImageConfigArgs>? = null

    private var mode: Output<String>? = null

    private var modelDataSource: Output<ModelContainerModelDataSourceArgs>? = null

    private var modelDataUrl: Output<String>? = null

    private var modelPackageName: Output<String>? = null

    /**
     * @param value The DNS host name for the container.
     */
    @JvmName("gquvoscblhevlmft")
    public suspend fun containerHostname(`value`: Output<String>) {
        this.containerHostname = value
    }

    /**
     * @param value Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("rogitpffdkaadnvu")
    public suspend fun environment(`value`: Output<Map<String, String>>) {
        this.environment = value
    }

    /**
     * @param value The registry path where the inference code image is stored in Amazon ECR.
     */
    @JvmName("ycjmrwdjfhifhycm")
    public suspend fun image(`value`: Output<String>) {
        this.image = value
    }

    /**
     * @param value Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("dthmtvqffwhbsyjj")
    public suspend fun imageConfig(`value`: Output<ModelContainerImageConfigArgs>) {
        this.imageConfig = value
    }

    /**
     * @param value The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
     */
    @JvmName("pryruxjnvntkkwuh")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("igvpatgxffslkpcw")
    public suspend fun modelDataSource(`value`: Output<ModelContainerModelDataSourceArgs>) {
        this.modelDataSource = value
    }

    /**
     * @param value The URL for the S3 location where model artifacts are stored.
     */
    @JvmName("ppdhwfwamfhlntmj")
    public suspend fun modelDataUrl(`value`: Output<String>) {
        this.modelDataUrl = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the model package to use to create the model.
     */
    @JvmName("lblcioxuftwkmqie")
    public suspend fun modelPackageName(`value`: Output<String>) {
        this.modelPackageName = value
    }

    /**
     * @param value The DNS host name for the container.
     */
    @JvmName("eptslgwldltendjf")
    public suspend fun containerHostname(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerHostname = mapped
    }

    /**
     * @param value Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("ffsdxplmetixeuit")
    public suspend fun environment(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environment = mapped
    }

    /**
     * @param values Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("spexsoxbybtjsufm")
    public fun environment(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environment = mapped
    }

    /**
     * @param value The registry path where the inference code image is stored in Amazon ECR.
     */
    @JvmName("fqilvxbudybycifn")
    public suspend fun image(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param value Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("uxjvuelaremriwdg")
    public suspend fun imageConfig(`value`: ModelContainerImageConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageConfig = mapped
    }

    /**
     * @param argument Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("etwxvicsxfireayl")
    public suspend
    fun imageConfig(argument: suspend ModelContainerImageConfigArgsBuilder.() -> Unit) {
        val toBeMapped = ModelContainerImageConfigArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.imageConfig = mapped
    }

    /**
     * @param value The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
     */
    @JvmName("iwsqmxmgedsleksx")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("bpvbhvruwtyxpwja")
    public suspend fun modelDataSource(`value`: ModelContainerModelDataSourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelDataSource = mapped
    }

    /**
     * @param argument The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("kiomsymdjjlkwrkv")
    public suspend
    fun modelDataSource(argument: suspend ModelContainerModelDataSourceArgsBuilder.() -> Unit) {
        val toBeMapped = ModelContainerModelDataSourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.modelDataSource = mapped
    }

    /**
     * @param value The URL for the S3 location where model artifacts are stored.
     */
    @JvmName("heivlinjntdskajq")
    public suspend fun modelDataUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelDataUrl = mapped
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the model package to use to create the model.
     */
    @JvmName("copcpocvlyadeelx")
    public suspend fun modelPackageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelPackageName = mapped
    }

    internal fun build(): ModelContainerArgs = ModelContainerArgs(
        containerHostname = containerHostname,
        environment = environment,
        image = image,
        imageConfig = imageConfig,
        mode = mode,
        modelDataSource = modelDataSource,
        modelDataUrl = modelDataUrl,
        modelPackageName = modelPackageName,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/sagemaker/kotlin/inputs/ModelContainerArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.sagemaker.kotlin.inputs

import com.pulumi.aws.sagemaker.inputs.ModelContainerArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property containerHostname The DNS host name for the container.
 * @property environment Environment variables for the Docker container.
 * A list of key value pairs.
 * @property image The registry path where the inference code image is stored in Amazon ECR.
 * @property imageConfig Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
 * @property mode The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
 * @property modelDataSource The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
 * @property modelDataUrl The URL for the S3 location where model artifacts are stored.
 * @property modelPackageName The Amazon Resource Name (ARN) of the model package to use to create the model.
 */
public data class ModelContainerArgs(
    public val containerHostname: Output<String>? = null,
    public val environment: Output<Map<String, String>>? = null,
    public val image: Output<String>? = null,
    public val imageConfig: Output<ModelContainerImageConfigArgs>? = null,
    public val mode: Output<String>? = null,
    public val modelDataSource: Output<ModelContainerModelDataSourceArgs>? = null,
    public val modelDataUrl: Output<String>? = null,
    public val modelPackageName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.sagemaker.inputs.ModelContainerArgs> {
    override fun toJava(): com.pulumi.aws.sagemaker.inputs.ModelContainerArgs =
        com.pulumi.aws.sagemaker.inputs.ModelContainerArgs.builder()
            .containerHostname(containerHostname?.applyValue({ args0 -> args0 }))
            .environment(
                environment?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .image(image?.applyValue({ args0 -> args0 }))
            .imageConfig(imageConfig?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .mode(mode?.applyValue({ args0 -> args0 }))
            .modelDataSource(modelDataSource?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .modelDataUrl(modelDataUrl?.applyValue({ args0 -> args0 }))
            .modelPackageName(modelPackageName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ModelContainerArgs].
 */
@PulumiTagMarker
public class ModelContainerArgsBuilder internal constructor() {
    private var containerHostname: Output<String>? = null

    private var environment: Output<Map<String, String>>? = null

    private var image: Output<String>? = null

    private var imageConfig: Output<ModelContainerImageConfigArgs>? = null

    private var mode: Output<String>? = null

    private var modelDataSource: Output<ModelContainerModelDataSourceArgs>? = null

    private var modelDataUrl: Output<String>? = null

    private var modelPackageName: Output<String>? = null

    /**
     * @param value The DNS host name for the container.
     */
    @JvmName("oyuwmpxgtuoetipc")
    public suspend fun containerHostname(`value`: Output<String>) {
        this.containerHostname = value
    }

    /**
     * @param value Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("woqlpefthsdvdejw")
    public suspend fun environment(`value`: Output<Map<String, String>>) {
        this.environment = value
    }

    /**
     * @param value The registry path where the inference code image is stored in Amazon ECR.
     */
    @JvmName("mcopmutklwtneevt")
    public suspend fun image(`value`: Output<String>) {
        this.image = value
    }

    /**
     * @param value Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("qghfgifkdprlwlfu")
    public suspend fun imageConfig(`value`: Output<ModelContainerImageConfigArgs>) {
        this.imageConfig = value
    }

    /**
     * @param value The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
     */
    @JvmName("joahtgkmchkmsnnn")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("pkivpnpkbdlkvrwq")
    public suspend fun modelDataSource(`value`: Output<ModelContainerModelDataSourceArgs>) {
        this.modelDataSource = value
    }

    /**
     * @param value The URL for the S3 location where model artifacts are stored.
     */
    @JvmName("seppyfcuarmmfkfa")
    public suspend fun modelDataUrl(`value`: Output<String>) {
        this.modelDataUrl = value
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the model package to use to create the model.
     */
    @JvmName("prieeisbeimigjem")
    public suspend fun modelPackageName(`value`: Output<String>) {
        this.modelPackageName = value
    }

    /**
     * @param value The DNS host name for the container.
     */
    @JvmName("irucemntvssihcyo")
    public suspend fun containerHostname(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.containerHostname = mapped
    }

    /**
     * @param value Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("lvqnmbdtwvdtttos")
    public suspend fun environment(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.environment = mapped
    }

    /**
     * @param values Environment variables for the Docker container.
     * A list of key value pairs.
     */
    @JvmName("xpfphmfxrsydxdsm")
    public fun environment(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.environment = mapped
    }

    /**
     * @param value The registry path where the inference code image is stored in Amazon ECR.
     */
    @JvmName("uouwyokkgyjacxsh")
    public suspend fun image(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.image = mapped
    }

    /**
     * @param value Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("wyvotexoqwdcqpdh")
    public suspend fun imageConfig(`value`: ModelContainerImageConfigArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageConfig = mapped
    }

    /**
     * @param argument Specifies whether the model container is in Amazon ECR or a private Docker registry accessible from your Amazon Virtual Private Cloud (VPC). For more information see [Using a Private Docker Registry for Real-Time Inference Containers](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-containers-inference-private.html). see Image Config.
     */
    @JvmName("gldxqgkppovbcfpb")
    public suspend fun imageConfig(argument: suspend ModelContainerImageConfigArgsBuilder.() -> Unit) {
        val toBeMapped = ModelContainerImageConfigArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.imageConfig = mapped
    }

    /**
     * @param value The container hosts value `SingleModel/MultiModel`. The default value is `SingleModel`.
     */
    @JvmName("joyfymovjgnwwpwy")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("smixrcpjvnsrxixl")
    public suspend fun modelDataSource(`value`: ModelContainerModelDataSourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelDataSource = mapped
    }

    /**
     * @param argument The location of model data to deploy. Use this for uncompressed model deployment. For information about how to deploy an uncompressed model, see [Deploying uncompressed models](https://docs.aws.amazon.com/sagemaker/latest/dg/large-model-inference-uncompressed.html) in the _AWS SageMaker Developer Guide_.
     */
    @JvmName("gebyafhjrhdqkrtb")
    public suspend fun modelDataSource(argument: suspend ModelContainerModelDataSourceArgsBuilder.() -> Unit) {
        val toBeMapped = ModelContainerModelDataSourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.modelDataSource = mapped
    }

    /**
     * @param value The URL for the S3 location where model artifacts are stored.
     */
    @JvmName("reohcoxbvhphmhep")
    public suspend fun modelDataUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelDataUrl = mapped
    }

    /**
     * @param value The Amazon Resource Name (ARN) of the model package to use to create the model.
     */
    @JvmName("ikcduneoucpufsgp")
    public suspend fun modelPackageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.modelPackageName = mapped
    }

    internal fun build(): ModelContainerArgs = ModelContainerArgs(
        containerHostname = containerHostname,
        environment = environment,
        image = image,
        imageConfig = imageConfig,
        mode = mode,
        modelDataSource = modelDataSource,
        modelDataUrl = modelDataUrl,
        modelPackageName = modelPackageName,
    )
}
